# aquapointer
Package applying quantum algorithms to find locations of water molecules in a protein cavity

## Getting started
You can use [this notebook](notebooks/aquapointer_demo.ipynb) to get started with aquapointer. 

## Installing aquapointer
From the top level of the repository, where the `setup.py` file is found, just run
```
python setup.py install
```